<?php

namespace Bgtest\Bgtest\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Bgtest\Bgtest\Http\Requests\ActivityLogRequest;
use Bgtest\Bgtest\Interfaces\ActivityLogRepositoryInterface;
use Bgtest\Bgtest\Models\ActivityLog;

class ActivityLogUserController extends BaseController
{
    /**
     * Initialize activity_log controller.
     *
     * @param type ActivityLogRepositoryInterface $activity_log
     *
     * @return type
     */
    public function __construct(ActivityLogRepositoryInterface $activity_log)
    {
        $this->repository = $activity_log;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Bgtest\Bgtest\Repositories\Criteria\ActivityLogUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ActivityLogRequest $request)
    {
        $activity_logs = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('bgtest::activity_log.names'));

        return $this->theme->of('bgtest::user.activity_log.index', compact('activity_logs'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param ActivityLog $activity_log
     *
     * @return Response
     */
    public function show(ActivityLogRequest $request, ActivityLog $activity_log)
    {
        Form::populate($activity_log);

        return $this->theme->of('bgtest::user.activity_log.show', compact('activity_log'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActivityLogRequest $request)
    {

        $activity_log = $this->repository->newInstance([]);
        Form::populate($activity_log);

        $this->theme->prependTitle(trans('bgtest::activity_log.names'));
        return $this->theme->of('bgtest::user.activity_log.create', compact('activity_log'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActivityLogRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $activity_log = $this->repository->create($attributes);

            return redirect(trans_url('/user/bgtest/activity_log'))
                -> with('message', trans('messages.success.created', ['Module' => trans('bgtest::activity_log.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param ActivityLog $activity_log
     *
     * @return Response
     */
    public function edit(ActivityLogRequest $request, ActivityLog $activity_log)
    {

        Form::populate($activity_log);
        $this->theme->prependTitle(trans('bgtest::activity_log.names'));

        return $this->theme->of('bgtest::user.activity_log.edit', compact('activity_log'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param ActivityLog $activity_log
     *
     * @return Response
     */
    public function update(ActivityLogRequest $request, ActivityLog $activity_log)
    {
        try {
            $this->repository->update($request->all(), $activity_log->getRouteKey());

            return redirect(trans_url('/user/bgtest/activity_log'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('bgtest::activity_log.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ActivityLogRequest $request, ActivityLog $activity_log)
    {
        try {
            $this->repository->delete($activity_log->getRouteKey());
            return redirect(trans_url('/user/bgtest/activity_log'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('bgtest::activity_log.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
