<?php

namespace Bgtest\Bgtest\Http\Controllers;
use Litepie\Bgtest\Http\Requests\ActivityLogRequest;
use Litepie\Bgtest\Models\ActivityLog;

trait ActivityLogWorkflow {
	
    /**
     * Workflow controller function for activity_log.
     *
     * @param Model   $activity_log
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ActivityLogRequest $request, ActivityLog $activity_log, $step)
    {

        try {

            $activity_log->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('bgtest::activity_log.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/activity_log/activity_log/' . $activity_log->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/activity_log/activity_log/' . $activity_log->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for activity_log.
     *
     * @param Model   $activity_log
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(ActivityLog $activity_log, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $activity_log->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('bgtest::activity_log.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('bgtest::admin.activity_log.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('bgtest::admin.activity_log.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('bgtest::admin.activity_log.message', $data)->render();

        }

    }
}