<?php

namespace Bgtest\Bgtest\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Bgtest\Bgtest\Interfaces\ActivityLogRepositoryInterface;
use Bgtest\Bgtest\Repositories\Presenter\ActivityLogItemTransformer;

/**
 * Pubic API controller class.
 */
class ActivityLogPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Bgtest\ActivityLog\Interfaces\ActivityLogRepositoryInterface $activity_log
     *
     * @return type
     */
    public function __construct(ActivityLogRepositoryInterface $activity_log)
    {
        $this->repository = $activity_log;
        parent::__construct();
    }

    /**
     * Show activity_log's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $activity_logs = $this->repository
            ->setPresenter('\\Bgtest\\Bgtest\\Repositories\\Presenter\\ActivityLogListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $activity_logs['code'] = 2000;
        return response()->json($activity_logs)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show activity_log.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $activity_log = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($activity_log)) {
            $activity_log         = $this->itemPresenter($module, new ActivityLogItemTransformer);
            $activity_log['code'] = 2001;
            return response()->json($activity_log)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
