<?php

namespace Bgtest\Bgtest\Policies;

use App\User;
use Bgtest\Bgtest\Models\ActivityLog;

class ActivityLogPolicy
{

    /**
     * Determine if the given user can view the activity_log.
     *
     * @param User $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function view(User $user, ActivityLog $activity_log)
    {
        if ($user->canDo('bgtest.activity_log.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $activity_log->user_id;
    }

    /**
     * Determine if the given user can create a activity_log.
     *
     * @param User $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('bgtest.activity_log.create');
    }

    /**
     * Determine if the given user can update the given activity_log.
     *
     * @param User $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function update(User $user, ActivityLog $activity_log)
    {
        if ($user->canDo('bgtest.activity_log.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $activity_log->user_id;
    }

    /**
     * Determine if the given user can delete the given activity_log.
     *
     * @param User $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function destroy(User $user, ActivityLog $activity_log)
    {
        if ($user->canDo('bgtest.activity_log.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $activity_log->user_id;
    }

    /**
     * Determine if the given user can verify the given activity_log.
     *
     * @param User $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function verify(User $user, ActivityLog $activity_log)
    {
        if ($user->canDo('bgtest.activity_log.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('bgtest.activity_log.verify') 
        && $user->is('manager')
        && $activity_log->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_log.
     *
     * @param User $user
     * @param ActivityLog $activity_log
     *
     * @return bool
     */
    public function approve(User $user, ActivityLog $activity_log)
    {
        if ($user->canDo('bgtest.activity_log.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
