<?php

namespace Bgtest\Bgtest\Providers;

use Illuminate\Support\ServiceProvider;

class BgtestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'bgtest');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'bgtest');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('bgtest', function ($app) {
            return $this->app->make('Bgtest\Bgtest\Bgtest');
        });

        // Bind ActivityLog to repository
        $this->app->bind(
            \Bgtest\Bgtest\Interfaces\ActivityLogRepositoryInterface::class,
            \Bgtest\Bgtest\Repositories\Eloquent\ActivityLogRepository::class
        );

        $this->app->register(\Bgtest\Bgtest\Providers\AuthServiceProvider::class);
        $this->app->register(\Bgtest\Bgtest\Providers\EventServiceProvider::class);
        $this->app->register(\Bgtest\Bgtest\Providers\RouteServiceProvider::class);
        // $this->app->register(\Bgtest\Bgtest\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bgtest'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('bgtest/bgtest.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/bgtest')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/bgtest')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
