<?php

namespace Bgtest\Bgtest\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Bgtest\Bgtest\Models\ActivityLog;

class ActivityLogAction
{
    /**
     * Perform the complete action.
     *
     * @param ActivityLog $activity_log
     *
     * @return ActivityLog
     */
    public function complete(ActivityLog $activity_log)
    {
        try {
            $activity_log->status = 'complete';
            return $activity_log->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ActivityLog $activity_log
     *
     * @return ActivityLog
     */public function verify(ActivityLog $activity_log)
    {
        try {
            $activity_log->status = 'verify';
            return $activity_log->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ActivityLog $activity_log
     *
     * @return ActivityLog
     */public function approve(ActivityLog $activity_log)
    {
        try {
            $activity_log->status = 'approve';
            return $activity_log->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ActivityLog $activity_log
     *
     * @return ActivityLog
     */public function publish(ActivityLog $activity_log)
    {
        try {
            $activity_log->status = 'publish';
            return $activity_log->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ActivityLog $activity_log
     *
     * @return ActivityLog
     */
    public function archive(ActivityLog $activity_log)
    {
        try {
            $activity_log->status = 'archive';
            return $activity_log->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ActivityLog $activity_log
     *
     * @return ActivityLog
     */
    public function unpublish(ActivityLog $activity_log)
    {
        try {
            $activity_log->status = 'unpublish';
            return $activity_log->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
